package com.zsc.edu.gateway.modules.system.controller;

import com.zsc.edu.gateway.framework.security.UserDetailsImpl;
import com.zsc.edu.gateway.modules.system.dto.MenuDto;
import com.zsc.edu.gateway.modules.system.entity.Menu;
import com.zsc.edu.gateway.modules.system.service.MenuService;
import com.zsc.edu.gateway.modules.system.utils.TreeUtil;
import com.zsc.edu.gateway.modules.system.vo.MenuVo;
import lombok.AllArgsConstructor;
import org.springframework.security.core.annotation.AuthenticationPrincipal;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @author zhuang
 */
@AllArgsConstructor
@RestController
@RequestMapping("/api/rest/menu")
public class MenuController {

    private final MenuService service;


    /**
     * 获取菜单树
     */
    @GetMapping("/menu")
    public List<MenuVo> menu(@AuthenticationPrincipal UserDetailsImpl userDetails) {
        List<MenuVo> list = service.selectByUserId(userDetails.getId(), Menu.Type.PAGE).stream().map(MenuVo::new).toList();
        return TreeUtil.makeTree(
                list,
                x -> x.getPid() == null,
                (x, y) -> x.getId().equals(y.getPid()),
                MenuVo::setChildren
        );
    }

    /**
     * 新建菜单
     */
    @PostMapping("")
    public Menu create(MenuDto dto) {
        return service.create(dto);
    }

    /**
     * 更新菜单
     */
    @PatchMapping("")
    public Menu update(MenuDto dto, Long id) {
        return service.update(dto, id);
    }

    /**
     * 删除菜单
     */
    @DeleteMapping("/{id}")
    public Boolean delete(@PathVariable Long id) {
        return service.delete(id);
    }
}
