package com.zsc.edu.gateway.modules.system.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.zsc.edu.gateway.exception.ConstraintException;
import com.zsc.edu.gateway.modules.system.dto.MenuDto;
import com.zsc.edu.gateway.modules.system.entity.Menu;
import com.zsc.edu.gateway.modules.system.entity.RoleMenu;
import com.zsc.edu.gateway.modules.system.mapper.MenuMapper;
import com.zsc.edu.gateway.modules.system.repo.MenuRepository;
import com.zsc.edu.gateway.modules.system.repo.RoleMenuRepository;
import com.zsc.edu.gateway.modules.system.service.MenuService;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @author zhuang
 */
@AllArgsConstructor
@Service
public class MenuServiceImpl extends ServiceImpl<MenuRepository, Menu> implements MenuService {
    private MenuMapper mapper;
    private RoleMenuRepository roleMenuRepository;
    @Override
    public List<Menu> selectByRoleId(Long roleId) {
        return baseMapper.selectByRoleId(roleId);
    }

    @Override
    public List<Menu> selectByUserId(Long userId, Menu.Type type) {
        return baseMapper.selectByUserId(userId, type);
    }

    @Override
    public Menu create(MenuDto dto) {
        Menu menu = mapper.toEntity(dto);
        baseMapper.insert(menu);
        return menu;
    }

    @Override
    public Menu update(MenuDto dto, Long id) {
        Menu menu = baseMapper.selectById(id);
        if (menu == null) {
            throw new ConstraintException("菜单不存在!请检查输入ID是否正确!");
        }
        mapper.convert(dto, menu);
        baseMapper.updateById(menu);
        return menu;
    }

    @Override
    public Boolean delete(Long id) {
        LambdaQueryWrapper<RoleMenu> queryWrapper = new LambdaQueryWrapper<>();
        roleMenuRepository.delete(queryWrapper.eq(RoleMenu::getMenuId, id));
        return removeById(id);
    }
}
